Glossary
--------

class:
   In general use, a class is a user-defined type with member functions.
   In C++, a class is a structure with private instance variables.

accessor function:
   A function that provides access (read or write) to a private instance
   variable.

invariant:
   A condition, usually pertaining to an object, that should be true at
   all times in client code, and that should be maintained by all member
   functions.

precondition:
   A condition that is assumed to be true at the beginning of a
   function. If the precondition is not true, the function may not work.
   It is often a good idea for functions to check their preconditions,
   if possible.

postcondition:
   A condition that is true at the end of a function.

.. dragndrop:: glossary_14
    :feedback: Try again!
    :match_1: class|||In general use, a class is a user-defined type with member functions. In C++, a class is a structure with private instance variables.
    :match_2: accessor function|||A function that provides access (read or write) to a private instance variable.
    :match_3: invariant|||A condition, usually pertaining to an object, that should be true at all times in client code, and that should be maintained by all member functions.
    :match_4: precondition|||A condition that is assumed to be true at the beginning of a function. If the precondition is not true, the function may not work. It is often a good idea for functions to check their preconditions, if possible.
    :match_5: postcondition|||A condition that is true at the end of a function.

    Match the vocabulary word with its definition.